# Gompertan plugin controller
require 'SVG/Graph/Line'

class GompertanController < ApplicationController
  unloadable
  
  layout 'base'  
  before_filter :find_project, :authorize

  def view
  end

  def graph
    data = graph_gompeltz
    if data
      headers["Content-Type"] = "image/svg+xml"
      send_data(data, :type => "image/svg+xml", :disposition => "inline")
    else
      render_404
    end
  end

private
  def find_project   
    @project=Project.find(params[:id])
  end

  def graph_gompeltz
    days = Setting.plugin_gompertan_plugin['show_days'].to_i
    date_from = Date.today - days + 1
    cond = @project.project_condition(true)
    issues_by_date ||=  Issue.count(:all, :conditions => ["(#{cond}) AND start_date BETWEEN ? AND ?", date_from, Date.today+1], :group => "start_date", :include => :project, :order => "start_date" )

    issues_new = [0] * days
    issues_sum = [0] * days
    issues_label = []

    days.times do |m| 
      issues_label << (date_from+m).strftime("%m/%d") 
      issues_by_date.each do |n| 
        if n.first.to_date===date_from+m
          issues_new[m] += n.last
        end
      end
    end

    issues_sum[0] = issues_new[0]
    1.upto(days-1) do |m|
      issues_sum[m] = issues_sum[m-1] + issues_new[m]
    end

    graph = SVG::Graph::Line.new(
      :height => 300,
      :width => 600,
      :fields => issues_label,
      :stack => :side,
      :scale_integers => true,
      :step_x_labels => days/6,
      :show_data_values => false,
      :graph_title => l(:gompertan_graph_title),
      :show_graph_title => true
    )
    
    graph.add_data(
      :data => issues_sum,
      :title => l(:gompertan_graph_issues_sum)
    )

    graph.add_data(
      :data => issues_new,
      :title => l(:gompertan_graph_issues_new)
    )
    
    graph.burn
  end

end
